@@ -5,17 +5,15 @@ use strict;
 use warnings;
 
 use Data::Dumper;
-use File::Slurp;
 use HTTP::Request::Common;
 use JSON qw(decode_json encode_json);
 use List::Util qw(first);
 use LWP::UserAgent;
-use MIME::Base64;
 use Mozilla::CA;
 use Scalar::Util;
 use XML::LibXML;
 
-our $VERSION = '1.0.6';
+our $VERSION = '1.0.8';
 
 use constant ENDPOINTS => {
     'IMGUR'           => 'https://api.imgur.com/3',
@@ -1357,49 +1355,95 @@ Get information about a specific album.
 
 =head5 album_create
 
-    $resp = $client->album_create({
-        ids         => \@image_ids,
-        title       => 'title',
-        description => 'description',
-        cover       => $image_id
-    });
+    $resp = $client->album_create(\%opts);
+
+=over 4
+
+=item *
+
+C<ids> - Array reference of image ids.
+
+=item *
+
+C<title> - Title of the album.
+
+=item *
+
+C<description> - Description of the album.
+
+=item *
+
+C<cover> - Image id of the cover image.
+
+=back
 
 =head5 album_delete
 
     $resp = $client->album_delete($album_id);
 
+Delete an album.
+
 =head5 album_favorite
 
     $resp = $client->album_favorite($album_id);
 
+Favorite an album.
+
 =head5 album_image
 
     $resp = $client->album_image($album_id, $image_id);
 
+Get information about a specific image in an album.
+
 =head5 album_images
 
     $resp = $client->album_images($album_id);
 
+Get all the images in an album.
+
 =head5 album_images_add
 
     $resp = $client->album_images_add($album_id, \@image_ids);
 
+Add images to an album.
+
 =head5 album_images_delete
 
     $resp = $client->album_images_delete($album_id, \@image_ids);
 
+Delete images from an album.
+
 =head5 album_images_set
 
     $resp = $client->album_images_set($album_id, \@image_ids);
 
+Set the images for an album.
+
 =head5 album_update
 
-    $resp = $client->album_update($album_id, {
-        ids         => [$image_id1, $image_id2],
-        title       => 'title',
-        description => 'description',
-        cover       => $image_id
-    });
+    $resp = $client->album_update($album_id, \%opts);
+
+Update an album. Valid options are:
+
+=over 4
+
+=item *
+
+C<ids> - Array reference of image ids.
+
+=item *
+
+C<title> - Title of the album.
+
+=item *
+
+C<description> - Description of the album.
+
+=item *
+
+C<cover> - Image id of the cover image.
+
+=back
 
 =head4 COMMENT
 
@@ -1437,9 +1481,37 @@ Create a new reply to a comment.
 
     $resp = $client->comment_report($comment_id, $reason);
 
+Report a comment with a reason. Valid reasons are:
+
+=over 4
+
+=item *
+
+C<1> - Doesn't belong on Imgur
+
+=item *
+
+C<2> - Spam
+
+=item *
+
+C<3> - Abusive
+
+=item *
+
+C<4> - Mature content not marked as mature
+
+=item *
+
+C<5> - Pornography
+
+=back
+
 =head5 comment_vote
 
-    $resp = $client->comment_vote($comment_id, 'up');
+    $resp = $client->comment_vote($comment_id, $vote);
+
+Cast a vote on a comment. Valid vote values are C<up>, C<down> and C<veto>.
 
 =head4 GALLERY
 
@@ -1449,65 +1521,145 @@ Create a new reply to a comment.
 
 Get gallery images.
 
+Validation options are:
+
+=over 4
+
+=item *
+
+C<section> - Section. Options are C<hot> (default), C<top> and C<user>.
+
+=item *
+
+C<sort> - Sort order. Options are C<viral> (default), C<top>, C<time>, C<rising>.
+
+=item *
+
+C<page> - Page number.
+
+=item *
+
+C<window> - Time window. Options are C<day>, C<week>, C<month>, C<year>, C<all>.
+
+=item *
+
+C<show_viral> - Show or hide viral images in the gallery. Default is C<1>.
+
+=item *
+
+C<album_previews> - Show or hide album previews in the gallery. Default is C<1>.
+
+=back
+
 =head5 gallery_album
 
     $resp = $client->gallery_album($album_id);
 
+Get information about a specific gallery album.
+
 =head5 gallery_image
 
     $resp = $client->gallery_image($image_id);
 
+Get information about a specific gallery image.
+
 =head5 gallery_item
 
     $resp = $client->gallery_item($item_id);
 
+Get information about a specific gallery item.
+
 =head5 gallery_item_comment
 
     $resp = $client->gallery_item_comment($item_id, $comment);
 
+Create a new comment on a gallery item.
+
 =head5 gallery_item_comment_info
 
     $resp = $client->gallery_item_comment_info($item_id, $comment_id);
 
+Get information about a specific comment on a gallery item.
+
 =head5 gallery_item_comments
 
     $resp = $client->gallery_item_comments($item_id);
 
+Get all the comments on a gallery item.
+
 =head5 gallery_item_report
 
     $resp = $client->gallery_item_report($item_id, \%opts);
 
+Report a gallery item. Valid options are:
+
+=over 4
+
+=item *
+
+C<reason> - Reason for reporting the item. Options are C<1> (doesn't belong on Imgur), C<2> (spam), C<3> (abusive), C<4> (mature content not marked as mature), C<5> (pornography).
+
+=back
+
 =head5 gallery_item_tags
 
     $resp = $client->gallery_item_tags($item_id);
 
+Get the tags for a gallery item.
+
 =head5 gallery_item_tags_update
 
     $resp = $client->gallery_item_tags_update($item_id, \@tags);
 
+Update the tags for a gallery item.
+
 =head5 gallery_item_vote
 
-    $resp = $client->gallery_item_vote($item_id, 'up');
+    $resp = $client->gallery_item_vote($item_id, $vote);
+
+Cast a vote on a gallery item. Valid vote values are C<up>, C<down> and C<veto>.
 
 =head5 gallery_item_votes
 
     $resp = $client->gallery_item_votes($item_id);
 
+Get the votes for a gallery item.
+
 =head5 gallery_image_remove
 
     $resp = $client->gallery_image_remove($image_id);
 
+Remove an image from the gallery.
+
 =head5 gallery_search
 
     $resp = $client->gallery_search('query', \%opts, \%advanced);
 
+Search the gallery. Valid options are:
+
+=over 4
+
+=item *
+
+C<sort> - Sort order. Options are C<time> (default),  C<viral>, C<top>, C<rising>.
+
+=item *
+
+C<window> - Time window. Options are C<all> (default), C<day>, C<week>, C<month>, C<year>.
+
+=item *
+
+C<page> - Page number.
+
+=back
+
 =head5 gallery_share_image
 
-    $resp = $client->gallery_share_image($image_id , 'title', \%opts);
+    $resp = $client->gallery_share_image($image_id , $title, \%opts);
 
 =head5 gallery_share_album
 
-    $resp = $client->gallery_share_album($album_id, 'title', \%opts);
+    $resp = $client->gallery_share_album($album_id, $title, \%opts);
 
 =head5 gallery_subreddit
 
@@ -1529,7 +1681,6 @@ Get gallery images.
 
     $resp = $client->gallery_tags;
 
-
 =head4 IMAGE
 
 =head5 image
@@ -1548,20 +1699,28 @@ Upload an image or video to imgur. The second argument is the type of the first
 
     $resp = $client->image_delete($image_id);
 
+Delete an image.
+
 =head5 image_favorite
 
     $resp = $client->image_favorite($image_id);
 
+Favorite an image.
+
 =head5 image_update
 
     $resp = $client->image_update($image_id, {title => 'title', description => 'description'});
 
+Update an image.
+
 =head4 FEED
 
 =head5 feed
 
     $resp = $client->feed;
 
+Get the authenticated user's feed.
+
 =head1 AUTHOR
 
 Dillan Hildebrand
